<SCRIPT RunAt=Server Language=VBScript>

'THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT 
'WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, 
'INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES 
'OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR 
'PURPOSE

'------------------------------------------------------------------------------
'
' NAME: ChgMsgCl
'
' FILE DESCRIPTION: Changes the message class of each new message that has
'                   arrived in a particular folder
'
' Copyright (c) CdoLive 1998. All rights reserved.
'               Http://www.cdolive.com
'               Mailto:samples@cdolive.com
'
' Portions:
' Copyright (c) Microsoft Corporation 1993-1997. All rights reserved.
'
'------------------------------------------------------------------------------

Option Explicit

'------------------------------------------------------------------------------
'	Global Variables
'------------------------------------------------------------------------------

Dim g_bstrDebug							' Debug String

'------------------------------------------------------------------------------
'	CONSTANTS
'------------------------------------------------------------------------------

'------------------------------------------------------------------------------
'	EVENT HANDLERS
'------------------------------------------------------------------------------

' DESCRIPTION: This event is fired when a new message is added to the folder
Public Sub Folder_OnMessageCreated

	Dim oSession						' Session
	Dim oCurrentMsg						' Current message
	Dim oFolder						' Current folder

	' Clear error buffer
	Err.Clear

	' Get session informationen
	Set oSession = EventDetails.Session

	' No errors detected ?
	If Err.Number = 0 Then

		' Write some logging
		Call DebugAppend(oSession.CurrentUser & " ChgMsgCl - Proccessing startet", False)

		' Get current folder
		Set oFolder = oSession.GetFolder(EventDetails.FolderID,Null)

		' No errors detected ?
		If Err.Number = 0 Then

			' Get current message
			Set oCurrentMsg = oSession.GetMessage(EventDetails.MessageID,Null)

			' Error detected ?
			If Not Err.Number = 0 Then

				' Error reading new message
				Call DebugAppend("Error - Could not read message", True)
			Else

				' Set current message to read
				oCurrentMsg.Unread = False

				' Remember subject of arrived message
				Call DebugAppend("New message with subject: <" & oCurrentMsg.Subject & "> arrived", False)

				' Change the message class of the arrived message
				oCurrentMsg.Type = "IPM.Note.YourMessageClass"
				oCurrentMsg.Update

				' Error detected ?
				If Not Err.Number = 0 Then

					' Error changing message class
					Call DebugAppend("Error - Could not change message class", True)
				Else

					' Message class successfully changed
					Call DebugAppend("Message class successfully changed", True)
				End If
			End If
		Else

			' Could not get current folder
			Call DebugAppend("Error - Could not get current folder", True)
		End If
	Else

		' Check for any possible sys errors
		Call DebugAppend("Undefinied Error detected", True)
	End If

	' Check if folder object is set
	If Not oFolder Is Nothing Then

		' Write some logging, including the folder name
		Call DebugAppend(oFolder.Name & " ChgMsgCl - Processing finished", False)
	Else

		' Write some logging, without the folder name
		Call DebugAppend("ChgMsgCl - Processing finished", False)
	End If

	' Release objects
	Set oSession = Nothing
	Set oCurrentMsg = Nothing
	Set oFolder = Nothing

	' Write results in the Scripting Agent log
	Script.Response = g_bstrDebug
End Sub

' DESCRIPTION: This event is fired when a message in the folder is changed
Public Sub Message_OnChange
	'Not used
End Sub

' DESCRIPTION: This event is fired when a message is deleted from the folder
Public Sub Folder_OnMessageDeleted
	'Not used
End Sub

' DESCRIPTION: This event is fired when the timer on the folder expires
Public Sub Folder_OnTimer
	'Not used
End Sub

'-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
'                  PRIVATE FUNCTIONS/SUBS
'-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+

'------------------------------------------------------------------------------
'   Name: DebugAppend
'   Area: Debug
'   Desc: Simple Debugging Function
'   Parm: String Text, Bool ErrorFlag
'------------------------------------------------------------------------------

Private Sub DebugAppend(bstrParm,boolErrChkFlag)

	If boolErrChkFlag = True Then
		If Err.Number <> 0 Then
			g_bstrDebug = g_bstrDebug & bstrParm & " - " & cstr(Err.Number) & " " & Err.Description & vbCrLf
			Err.Clear
		End If
	Else
		g_bstrDebug = g_bstrDebug & bstrParm & vbCrLf
	End If

End Sub

</SCRIPT>
